package TestApp;

use strict;
use warnings;

use Catalyst::Runtime '5.70';
use Catalyst;

our $VERSION = '0.01';

## Configure the application.
#__PACKAGE__->config(
#   name        => 'TestApp',
#   bootstrap   => '/'
#);

# Start the application
#__PACKAGE__->setup;


1;
